<?php
/**
* Body Classes.
*
* @package Meganizer
*/
 
 if (!function_exists('meganizer_body_classes')) :

    function meganizer_body_classes($classes) {

        $meganizer_default = meganizer_get_default_theme_options();
        global $post;

        // Adds a class of hfeed to non-singular pages.
        if ( !is_singular() ) {
            $classes[] = 'hfeed';
        }

        // Adds a class of no-sidebar when there is no sidebar present.
        if ( !is_active_sidebar( 'sidebar-1' ) ) {
            $classes[] = 'no-sidebar';
        }
        
        if ( is_active_sidebar( 'sidebar-1' ) ) {

            $global_sidebar_layout = esc_html( get_theme_mod( 'global_sidebar_layout',$meganizer_default['global_sidebar_layout'] ) );

            if( is_single() || is_page() ){

                $meganizer_post_sidebar = esc_html( get_post_meta( $post->ID, 'meganizer_post_sidebar_option', true ) );

                if( $meganizer_post_sidebar == 'global-sidebar' || empty( $meganizer_post_sidebar ) ){

                    if( class_exists('WooCommerce') && ( is_cart() || is_checkout() ) ){
                        
                        $classes[] = 'no-sidebar';

                    }else{

                        $classes[] = esc_attr( $global_sidebar_layout );

                    }

                }else{

                    if( class_exists('WooCommerce') && ( is_cart() || is_checkout() ) ){
                        
                        $classes[] = 'no-sidebar';

                    }else{

                        $classes[] = esc_attr( $meganizer_post_sidebar );

                    }
                }
                
            }elseif( is_404() ){

                $classes[] = 'no-sidebar';

            }else{
                
                $classes[] = esc_attr( $global_sidebar_layout );
            }

        }
        if (is_active_sidebar('meganizer-offcanvas-widget')){
            $classes[] = 'offcanvas-on';
        }
        if( is_page() ){

            $meganizer_header_trending_page = get_theme_mod( 'meganizer_header_trending_page' );
            $meganizer_header_popular_page = get_theme_mod( 'meganizer_header_popular_page' );

            if( $meganizer_header_trending_page == $post->ID || $meganizer_header_popular_page == $post->ID ){

                $meganizer_archive_layout = get_theme_mod( 'meganizer_archive_layout',$meganizer_default['meganizer_archive_layout'] );
                $ed_image_content_inverse = get_theme_mod( 'ed_image_content_inverse',$meganizer_default['ed_image_content_inverse'] );
                if( $meganizer_archive_layout == 'default' && $ed_image_content_inverse ){

                    $classes[] = 'twp-archive-alternative';

                }

                $classes[] = 'twp-archive-'.esc_attr( $meganizer_archive_layout );
                
            }

        }

        if( is_singular('post') ){

            $meganizer_post_layout = esc_html( get_post_meta( $post->ID, 'meganizer_post_layout', true ) );

            if( $meganizer_post_layout == '' || $meganizer_post_layout == 'global-layout' ){
                
                $meganizer_post_layout = get_theme_mod( 'meganizer_single_post_layout',$meganizer_default['meganizer_archive_layout'] );

            }

            $classes[] = 'twp-single-'.esc_attr( $meganizer_post_layout );

            if( $meganizer_post_layout == 'layout-2' ){
                
                $meganizer_header_overlay = esc_html( get_post_meta( $post->ID, 'meganizer_header_overlay', true ) );

                if( $meganizer_header_overlay == '' || $meganizer_header_overlay == 'global-layout' ){

                    $meganizer_post_layout2 = get_theme_mod( 'meganizer_single_post_layout',$meganizer_default['meganizer_archive_layout'] );

                    if( $meganizer_post_layout2 == 'layout-2' ){

                        $ed_header_overlay = esc_html( get_post_meta( $post->ID, 'ed_header_overlay', true ) );
                        if( $ed_header_overlay == '' || $ed_header_overlay == 'global-layout' ){
                            
                            $ed_header_overlay = get_theme_mod( 'ed_header_overlay',$meganizer_default['ed_header_overlay'] );
                        }

                    }else{

                        $ed_header_overlay = false;

                    }

                }else{

                    $ed_header_overlay = true;

                }
                if( $ed_header_overlay ){

                    $classes[] = 'twp-single-header-overlay';

                }

            }

        }

        if( is_singular('page') ){

            $meganizer_page_layout = get_post_meta( $post->ID, 'meganizer_page_layout', true );

            if( $meganizer_page_layout == ''  ){
                
                $meganizer_page_layout = 'layout-1';

            }

            $classes[] = 'theme-single-'.esc_attr( $meganizer_page_layout );

            if( $meganizer_page_layout == 'layout-2' ){
                
                $meganizer_ed_header_overlay = get_post_meta( $post->ID, 'meganizer_ed_header_overlay', true );
                if( $meganizer_ed_header_overlay ){
                    $classes[] = 'theme-single-header-overlay';
                }

            }

        }

        if( is_archive() || is_home() || is_search() ){

            $meganizer_archive_layout = get_theme_mod( 'meganizer_archive_layout',$meganizer_default['meganizer_archive_layout'] );
            $ed_image_content_inverse = get_theme_mod( 'ed_image_content_inverse',$meganizer_default['ed_image_content_inverse'] );
            if( $meganizer_archive_layout == 'default' && $ed_image_content_inverse ){

                $classes[] = 'twp-archive-alternative';

            }

            $classes[] = 'twp-archive-'.esc_attr( $meganizer_archive_layout );
            
        }

        if( is_singular('post') ){

            $meganizer_ed_post_reaction = esc_html( get_post_meta( $post->ID, 'meganizer_ed_post_reaction', true ) );
            if( $meganizer_ed_post_reaction ){
                $classes[] = 'hide-comment-rating';
            }

        }

        return $classes;
    }

endif;

add_filter('body_class', 'meganizer_body_classes');