<?php
/**
* Custom Functions.
*
* @package Meganizer
*/


if( !function_exists( 'meganizer_sanitize_sidebar_option' ) ) :

    // Sidebar Option Sanitize.
    function meganizer_sanitize_sidebar_option( $meganizer_input ){

        $meganizer_metabox_options = array( 'global-sidebar','left-sidebar','right-sidebar','no-sidebar' );
        if( in_array( $meganizer_input,$meganizer_metabox_options ) ){

            return $meganizer_input;

        }

        return;

    }

endif;

if( !function_exists( 'meganizer_sanitize_single_pagination_layout' ) ) :

    // Sidebar Option Sanitize.
    function meganizer_sanitize_single_pagination_layout( $meganizer_input ){

        $meganizer_single_pagination = array( 'no-navigation','norma-navigation','ajax-next-post-load' );
        if( in_array( $meganizer_input,$meganizer_single_pagination ) ){

            return $meganizer_input;

        }

        return;

    }

endif;

if( !function_exists( 'meganizer_sanitize_archive_layout' ) ) :

    // Sidebar Option Sanitize.
    function meganizer_sanitize_archive_layout( $meganizer_input ){

        $meganizer_archive_option = array( 'default','full','grid' );
        if( in_array( $meganizer_input,$meganizer_archive_option ) ){

            return $meganizer_input;

        }

        return;

    }

endif;

if( !function_exists( 'meganizer_sanitize_single_post_layout' ) ) :

    // Single Layout Option Sanitize.
    function meganizer_sanitize_single_post_layout( $meganizer_input ){

        $meganizer_single_layout = array( 'layout-1','layout-2' );
        if( in_array( $meganizer_input,$meganizer_single_layout ) ){

            return $meganizer_input;

        }

        return;

    }

endif;

if ( ! function_exists( 'meganizer_sanitize_checkbox' ) ) :

	/**
	 * Sanitize checkbox.
	 */
	function meganizer_sanitize_checkbox( $meganizer_checked ) {

		return ( ( isset( $meganizer_checked ) && true === $meganizer_checked ) ? true : false );

	}

endif;


if ( ! function_exists( 'meganizer_sanitize_select' ) ) :

    /**
     * Sanitize select.
     */
    function meganizer_sanitize_select( $meganizer_input, $meganizer_setting ) {

        // Ensure input is a slug.
        $meganizer_input = sanitize_text_field( $meganizer_input );

        // Get list of choices from the control associated with the setting.
        $choices = $meganizer_setting->manager->get_control( $meganizer_setting->id )->choices;

        // If the input is a valid key, return it; otherwise, return the default.
        return ( array_key_exists( $meganizer_input, $choices ) ? $meganizer_input : $meganizer_setting->default );

    }

endif;

if ( ! function_exists( 'meganizer_sanitize_repeater' ) ) :
    
    /**
    * Sanitise Repeater Field
    */
    function meganizer_sanitize_repeater($input){
        $input_decoded = json_decode( $input, true );
        
        if(!empty($input_decoded)) {

            foreach ($input_decoded as $boxes => $box ){

                foreach ($box as $key => $value){

                    if( $key == 'section_ed' 
                        || $key == 'ed_tab' 
                        || $key == 'ed_arrows_carousel' 
                        || $key == 'ed_dots_carousel' 
                        || $key == 'ed_autoplay_carousel' 
                        || $key == 'ed_flip_column' 
                        || $key == 'ed_ribbon_bg'
                    ){

                        $input_decoded[$boxes][$key] = meganizer_sanitize_repeater_ed( $value );

                    }elseif( $key == 'home_section_type' ){

                        $input_decoded[$boxes][$key] = meganizer_sanitize_home_sections( $value );

                    }elseif( $key == 'ribbon_bg_color_schema' ){

                        $input_decoded[$boxes][$key] = meganizer_sanitize_ribbon_bg( $value );

                    }elseif( $key == 'category_color' ){

                        $input_decoded[$boxes][$key] = sanitize_hex_color( $value );

                    }elseif( $key == 'tiles_post_per_page' ){

                        $input_decoded[$boxes][$key] =  absint( $value );

                    }elseif( $key == 'advertise_image' || $key == 'advertise_link' ){

                         $input_decoded[$boxes][$key] = esc_url_raw( $value );

                    }elseif($key == 'section_category' || 
                            $key == 'section_post_slide_cat' || 
                            $key == 'section_post_cat_1' || 
                            $key == 'section_category_1' || 
                            $key == 'section_category_2' || 
                            $key == 'section_category_3' || 
                            $key == 'section_category_4' || 
                            $key == 'category'
                        ){

                        $input_decoded[$boxes][$key] =  meganizer_sanitize_category( $value );

                    }else{

                        $input_decoded[$boxes][$key] = sanitize_text_field( $value );

                    }
                    
                }

            }
           
            return json_encode($input_decoded);

        }

        return $input;
    }
endif;

/** Sanitize Enable Disable Checkbox **/
function meganizer_sanitize_repeater_ed( $input ) {

    $valid_keys = array('yes','no');
    if ( in_array( $input , $valid_keys ) ) {
        return $input;
    }
    return '';

}

function meganizer_sanitize_home_sections( $input ) {

    $home_sections = array(
        'default-banner-area' => esc_html__('Default Banner','meganizer'),
        'tiles-blocks' => esc_html__('Slider & Tiles Block','meganizer'),
        'main-banner' => esc_html__('Main Banner','meganizer'),
        'must-read' => esc_html__('Must Read','meganizer'),
        'banner-blocks-1' => esc_html__('Featured & Tab Block','meganizer'),
        'latest-posts-blocks' => esc_html__('Latest Posts Block','meganizer'),
        'slider-blocks' => esc_html__('Slider Block','meganizer'),
        'advertise-blocks' => esc_html__('Advertise Block','meganizer'),
        'home-widget-area' => esc_html__('Widgets Area Block','meganizer'),
        'you-may-like-blocks' => esc_html__('You May Like Block','meganizer'),

    );
    if ( array_key_exists( $input , $home_sections ) ) {
        return $input;
    }
    return '';

}

/** Sanitize Category **/
function meganizer_sanitize_category( $input ) {

   $meganizer_post_category_list = meganizer_post_category_list();
    if ( array_key_exists( $input , $meganizer_post_category_list ) ) {
        return $input;
    }
    return '';

}

function meganizer_sanitize_ribbon_bg( $input ) {

    $ribbon_bg = array( 
                    '1' =>  array(
                                    'title' =>  esc_html__( 'Blue', 'meganizer' ),
                                    'color' =>  '#3061ff',
                                ),
                    '2' =>  array(
                                    'title' =>  esc_html__( 'Orange', 'meganizer' ),
                                    'color' =>  '#fa9000',
                                ),
                    '3' =>  array(
                                    'title' =>  esc_html__( 'Royal Blue', 'meganizer' ),
                                    'color' =>  '#00167a',
                                ),
                    '4' =>  array(
                                    'title' =>  esc_html__( 'Pink', 'meganizer' ),
                                    'color' =>  '#ff2d55',
                                ),
                );

    if ( array_key_exists( $input , $ribbon_bg ) ) {
        return $input;
    }
    return '';

}